# Weatherflow4py

Simple Python library used by Home Assistant to interact with the WeatherFlow RESTApi


It supports Rest and WebSockets


### Utilizes these resources

- https://apidocs.tempestwx.com/reference/quick-start
- https://weatherflow.github.io/Tempest/api/swagger/
- https://weatherflow.github.io/Tempest/api/ws.html


- [PyPi Link](https://pypi.org/project/weatherflow4py/)
- [Test PyPi Link](https://test.pypi.org/project/weatherflow4py/)
